@@ -25,14 +25,14 @@
 
 // OpenBabel includes
 #include <openbabel/obconversion.h>
-#include <KDialog>
+#include <QDialog>
 class QDialog;
 
 /**
  * @author Carsten Niehaus
  * @author Jerome Pansanel
  */
-class KOpenBabel : public KDialog
+class KOpenBabel : public QDialog
 {
     Q_OBJECT
 
@@ -93,6 +93,11 @@ private slots:
      */
     void slotConvert();
 
+    /**
+     * Open help page
+     */
+    void slotHelpRequested();
+
 };
 
 #endif // OBCONVERTER_H
